pub struct MetricsSummary {Show 15 fields
pub total_sessions: u64,
pub total_tokens: TokenUsage,
pub total_tool_calls: u64,
pub active_sessions: u64,
pub prompt_cached_tool_outputs: u64,
pub tool_context_tokens_saved: u64,
pub total_compression_events: u64,
pub total_tokens_saved: u64,
pub non_tool_compression_tokens_saved: u64,
pub completed_sessions: u64,
pub awaiting_response_sessions: u64,
pub error_sessions: u64,
pub cancelled_sessions: u64,
pub total_sync_mismatches: u64,
pub sync_mismatch_breakdown: HashMap<String, u64>,
}Expand description
Overall metrics summary
Fields
total_sessions: u64Total number of sessions
total_tokens: TokenUsageTotal token usage
total_tool_calls: u64Total number of tool calls
active_sessions: u64Number of currently active sessions
prompt_cached_tool_outputs: u64Total number of prompt-side cached tool outputs.
tool_context_tokens_saved: u64Total tokens saved by prompt-side tool output compaction.
total_compression_events: u64Total number of context compression events.
total_tokens_saved: u64Total tokens saved by context compression.
non_tool_compression_tokens_saved: u64Total tokens saved by non-tool context compression.
completed_sessions: u64Number of completed sessions in the selected range.
awaiting_response_sessions: u64Number of sessions currently paused awaiting an external response.
error_sessions: u64Number of sessions that ended with an error.
cancelled_sessions: u64Number of sessions cancelled by the user.
total_sync_mismatches: u64Total number of execute sync mismatches observed for the filtered period.
sync_mismatch_breakdown: HashMap<String, u64>Breakdown of execute sync mismatches by stable reason label.