pub struct SessionMetrics {Show 14 fields
pub session_id: String,
pub model: String,
pub started_at: DateTime<Utc>,
pub completed_at: Option<DateTime<Utc>>,
pub total_rounds: u32,
pub total_token_usage: TokenUsage,
pub tool_call_count: u32,
pub tool_breakdown: HashMap<String, u32>,
pub status: SessionStatus,
pub message_count: u32,
pub duration_ms: Option<u64>,
pub prompt_cached_tool_outputs: u64,
pub total_compression_events: u64,
pub total_tokens_saved: u64,
}Expand description
Metrics for an entire session
Fields
session_id: StringUnique session identifier
model: StringModel used for this session
started_at: DateTime<Utc>When the session started
completed_at: Option<DateTime<Utc>>When the session completed
total_rounds: u32Total number of rounds in the session
total_token_usage: TokenUsageTotal token usage across all rounds
tool_call_count: u32Total number of tool calls
tool_breakdown: HashMap<String, u32>Breakdown of tool calls by tool name
status: SessionStatusSession execution status
message_count: u32Total number of messages exchanged
duration_ms: Option<u64>Session duration in milliseconds
prompt_cached_tool_outputs: u64Total number of prompt-side cached tool outputs observed across rounds.
total_compression_events: u64Total number of context compression events across all rounds.
total_tokens_saved: u64Total tokens saved by context compression across all rounds.