pub struct MetricsWorker { /* private fields */ }Expand description
Worker that consumes metrics events from the bus and writes them to storage
Implementations
Sourceimpl MetricsWorker
impl MetricsWorker
Sourcepub fn new(storage: Arc<dyn MetricsStorage>) -> Self
pub fn new(storage: Arc<dyn MetricsStorage>) -> Self
Create a new metrics worker with the given storage backend
Sourcepub fn spawn(
&self,
receiver: Receiver<MetricsEvent>,
bus: MetricsBus,
) -> Arc<AtomicBool>
pub fn spawn( &self, receiver: Receiver<MetricsEvent>, bus: MetricsBus, ) -> Arc<AtomicBool>
Spawn the worker task
Returns a handle to stop the worker