pub enum GuardianPhase {
None,
Pending,
Reviewed,
}Expand description
Lifecycle phase of the current guardian review pass.
Variants
None
No review is outstanding for the current terminal point.
Pending
A guardian child has been spawned and a verdict is awaited.
Reviewed
A verdict has been recorded for the current terminal point.
Implementations
Sourceimpl GuardianPhase
impl GuardianPhase
pub fn as_str(self) -> &'static str
Sourcepub fn is_pending(self) -> bool
pub fn is_pending(self) -> bool
Whether a guardian child is currently in flight.
Sourcepub fn is_reviewed(self) -> bool
pub fn is_reviewed(self) -> bool
Whether a verdict has already been recorded for this pass.