Module types

Module types 

Structs

ChatTurnInput
Input for the chat turn use case.
ExecuteClientSync
Client-side sync state sent with execute requests.
ExecuteInput
Input for the execute preparation use case.
ExecuteSyncInfo
Sync info to include in execute responses.
ExecutionConfigSnapshot
Resolved configuration snapshot for execution.
PreparedChatTurn
Outcome of preparing a chat turn.
RespondInput
Input for the respond use case.
ResumeConfigSnapshot
Resolved configuration snapshot for resume execution.
ServerExecuteSnapshot
Server-side snapshot of session state used for sync comparison.
SubmitResponseOutcome
Outcome of submitting a pending response.

Enums

ExecutePreparationOutcome
Outcome of preparing an execute.
ExecuteSyncReason
Reason for a sync mismatch between client and server.
ResumeOutcome
Outcome of a resume attempt.