pub struct ResumeConfigSnapshot {Show 14 fields
pub provider_name: String,
pub provider_type: Option<String>,
pub fast_model: Option<String>,
pub fast_model_ref: Option<ProviderModelRef>,
pub background_model: Option<String>,
pub background_model_ref: Option<ProviderModelRef>,
pub background_model_provider: Option<Arc<dyn LLMProvider>>,
pub summarization_model: Option<String>,
pub summarization_model_ref: Option<ProviderModelRef>,
pub summarization_model_provider: Option<Arc<dyn LLMProvider>>,
pub disabled_tools: BTreeSet<String>,
pub disabled_skill_ids: BTreeSet<String>,
pub image_fallback: Option<ImageFallbackConfig>,
pub gold_config: Option<GoldConfig>,
}Expand description
Resolved configuration snapshot for resume execution.
Captures the subset of config needed to spawn a resumed agent loop, decoupled from the full server config.
Fields
provider_name: Stringprovider_type: Option<String>fast_model: Option<String>fast_model_ref: Option<ProviderModelRef>background_model: Option<String>background_model_ref: Option<ProviderModelRef>background_model_provider: Option<Arc<dyn LLMProvider>>summarization_model: Option<String>summarization_model_ref: Option<ProviderModelRef>summarization_model_provider: Option<Arc<dyn LLMProvider>>disabled_tools: BTreeSet<String>disabled_skill_ids: BTreeSet<String>image_fallback: Option<ImageFallbackConfig>gold_config: Option<GoldConfig>Trait Implementations
Sourceimpl Clone for ResumeConfigSnapshot
impl Clone for ResumeConfigSnapshot
Sourcefn clone(&self) -> ResumeConfigSnapshot
fn clone(&self) -> ResumeConfigSnapshot
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl !RefUnwindSafe for ResumeConfigSnapshot
impl !UnwindSafe for ResumeConfigSnapshot
impl Freeze for ResumeConfigSnapshot
impl Send for ResumeConfigSnapshot
impl Sync for ResumeConfigSnapshot
impl Unpin for ResumeConfigSnapshot
impl UnsafeUnpin for ResumeConfigSnapshot