pub struct SessionCacheMap { /* private fields */ }Expand description
Both the index and the values use atomic publication. Unlike a DashMap guard, a returned entry does not hold a shard lock while cloning a transcript.
Implementations
Sourceimpl SessionCacheMap
impl SessionCacheMap
pub fn new() -> Self
pub fn insert(&self, id: String, snapshot: Arc<SessionSnapshot>)
pub fn get(&self, id: &str) -> Option<SessionCacheEntry>
pub fn remove(&self, id: &str) -> Option<(String, Arc<SessionSnapshot>)>
pub fn iter(&self) -> impl Iterator<Item = SessionCacheEntry> + '_
pub fn contains_key(&self, id: &str) -> bool
pub fn len(&self) -> usize
pub fn is_empty(&self) -> bool
pub fn clear(&self)