pub struct SkillManager { /* private fields */ }Expand description
Skill manager instance (convenience wrapper around SkillStore).
Implementations
Sourceimpl SkillManager
impl SkillManager
Sourcepub fn with_config(config: SkillStoreConfig) -> Self
pub fn with_config(config: SkillStoreConfig) -> Self
Create a new skill manager with custom configuration.
Sourcepub async fn initialize(&self) -> SkillResult<()>
pub async fn initialize(&self) -> SkillResult<()>
Initialize the manager.
Sourcepub fn store(&self) -> &SkillStore
pub fn store(&self) -> &SkillStore
Get the underlying store.
Sourcepub async fn build_skill_context_for_selection(
&self,
disabled_skill_ids: &BTreeSet<String>,
selected_skill_ids: Option<&[String]>,
) -> String
pub async fn build_skill_context_for_selection( &self, disabled_skill_ids: &BTreeSet<String>, selected_skill_ids: Option<&[String]>, ) -> String
Build system prompt context from a selected subset of skills.
Sourcepub async fn build_skill_context_for_selection_with_mode(
&self,
disabled_skill_ids: &BTreeSet<String>,
selected_skill_ids: Option<&[String]>,
selected_skill_mode: Option<&str>,
) -> String
pub async fn build_skill_context_for_selection_with_mode( &self, disabled_skill_ids: &BTreeSet<String>, selected_skill_ids: Option<&[String]>, selected_skill_mode: Option<&str>, ) -> String
Build system prompt context from a selected subset of skills with mode override.
pub async fn resolve_skills_for_request_with_mode( &self, disabled_skill_ids: &BTreeSet<String>, selected_skill_ids: Option<&[String]>, selected_skill_mode: Option<&str>, request_hint: Option<&str>, ) -> Vec<SkillDefinition>
Sourcepub async fn build_skill_context_for_request_with_mode(
&self,
disabled_skill_ids: &BTreeSet<String>,
selected_skill_ids: Option<&[String]>,
selected_skill_mode: Option<&str>,
request_hint: Option<&str>,
) -> String
pub async fn build_skill_context_for_request_with_mode( &self, disabled_skill_ids: &BTreeSet<String>, selected_skill_ids: Option<&[String]>, selected_skill_mode: Option<&str>, request_hint: Option<&str>, ) -> String
Build system prompt context from a selected subset of skills with mode and user request hint.
Sourcepub async fn build_skill_context(
&self,
disabled_skill_ids: &BTreeSet<String>,
_chat_id: Option<&str>,
) -> String
pub async fn build_skill_context( &self, disabled_skill_ids: &BTreeSet<String>, _chat_id: Option<&str>, ) -> String
Build system prompt context from all skills.
Sourcepub async fn get_allowed_tools_for_selection(
&self,
disabled_skill_ids: &BTreeSet<String>,
selected_skill_ids: Option<&[String]>,
) -> Vec<String>
pub async fn get_allowed_tools_for_selection( &self, disabled_skill_ids: &BTreeSet<String>, selected_skill_ids: Option<&[String]>, ) -> Vec<String>
Get allowed tool refs from a selected subset of skills.