ScriptHook

Struct ScriptHook 

pub struct ScriptHook { /* private fields */ }
One config-driven lifecycle script executed by an installed system runtime.

Scripts receive Bamboo’s versioned hook envelope on stdin and emit the same JSON response protocol as command hooks on stdout.

Implementations

Source

impl ScriptHook

pub fn new( event: LifecycleHookEvent, path: impl Into<String>, runner: LifecycleScriptRunner, timeout_ms: u64, matcher: Option<&str>, fallback_cwd: Option<PathBuf>, sequence: usize, ) -> Result<ScriptHook, Error>