pub trait WorkflowDefinitionPort: Send + Sync {
// Required method
fn pin_bundle<'life0, 'life1, 'async_trait>(
&'life0 self,
root: &'life1 WorkflowRunDefinition,
) -> Pin<Box<dyn Future<Output = Result<WorkflowDefinitionBundle, String>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait;
}Required Methods
Sourcefn pin_bundle<'life0, 'life1, 'async_trait>(
&'life0 self,
root: &'life1 WorkflowRunDefinition,
) -> Pin<Box<dyn Future<Output = Result<WorkflowDefinitionBundle, String>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn pin_bundle<'life0, 'life1, 'async_trait>(
&'life0 self,
root: &'life1 WorkflowRunDefinition,
) -> Pin<Box<dyn Future<Output = Result<WorkflowDefinitionBundle, String>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Pin the root and every transitively referenced nested definition from one immutable catalog publication. Implementations must never re-read a live source while constructing the returned bundle.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".