Prompt context builders (extracted from server layer).
Stateless functions that construct workspace, environment, and instruction context for the agent system prompt.
Modules
- instruction
- Instruction layer: loads instruction files (AGENTS.md, CLAUDE.md) from workspace.
Constants
- DEFAULT_
BASE_ PROMPT - ENV_
CONTEXT_ END_ MARKER - ENV_
CONTEXT_ START_ MARKER - WORKSPACE_
CONTEXT_ END_ MARKER - WORKSPACE_
CONTEXT_ PREFIX - WORKSPACE_
CONTEXT_ START_ MARKER
Functions
- assemble_
system_ prompt - Assemble a full system prompt from base prompt, optional enhancement, and context segments.
- build_
env_ prompt_ context - build_
workspace_ prompt_ context - workspace_
prompt_ guidance - Guidance for workspace-based interactions