SessionExecutionArgs

Struct SessionExecutionArgs 

pub struct SessionExecutionArgs {
Show 20 fields pub agent: Arc<Agent>, pub session_id: String, pub session: Session, pub tools_override: Option<Arc<dyn ToolExecutor>>, pub provider_override: Option<Arc<dyn LLMProvider>>, pub provider_name: Option<String>, pub model: String, pub fast_model: Option<String>, pub background_model_provider: Option<Arc<dyn LLMProvider>>, pub reasoning_effort: Option<ReasoningEffort>, pub reasoning_effort_source: String, pub disabled_tools: Option<BTreeSet<String>>, pub disabled_skill_ids: Option<BTreeSet<String>>, pub selected_skill_ids: Option<Vec<String>>, pub selected_skill_mode: Option<String>, pub cancel_token: CancellationToken, pub mpsc_tx: Sender<AgentEvent>, pub image_fallback: Option<ImageFallbackConfig>, pub runners: Arc<RwLock<HashMap<String, AgentRunner>>>, pub sessions_cache: Arc<RwLock<HashMap<String, Session>>>,
}
Arguments for spawning a background agent execution.

This is the crate-agnostic equivalent of the server’s SpawnAgentExecution. It holds everything needed to run the agent loop and persist the result, without depending on HTTP types or AppState.

Fields

agent: Arc<Agent>session_id: Stringsession: Sessiontools_override: Option<Arc<dyn ToolExecutor>>provider_override: Option<Arc<dyn LLMProvider>>provider_name: Option<String>model: Stringfast_model: Option<String>background_model_provider: Option<Arc<dyn LLMProvider>>

Optional provider override for background/fast model calls.

reasoning_effort: Option<ReasoningEffort>reasoning_effort_source: Stringdisabled_tools: Option<BTreeSet<String>>disabled_skill_ids: Option<BTreeSet<String>>selected_skill_ids: Option<Vec<String>>selected_skill_mode: Option<String>cancel_token: CancellationTokenmpsc_tx: Sender<AgentEvent>image_fallback: Option<ImageFallbackConfig>runners: Arc<RwLock<HashMap<String, AgentRunner>>>sessions_cache: Arc<RwLock<HashMap<String, Session>>>