Sub-session spawn scheduler.
Provides a background queue for spawning child sessions. Spawn is async (tool returns immediately), but the UI can observe child progress via events forwarded to the parent session stream.
Sub-session spawn scheduler.
Provides a background queue for spawning child sessions. Spawn is async (tool returns immediately), but the UI can observe child progress via events forwarded to the parent session stream.