pub struct HookRunner { /* private fields */ }Expand description
Runs registered hooks at a given hook point.
Implementations
Sourceimpl HookRunner
impl HookRunner
pub fn new() -> Self
Sourcepub fn register(&mut self, hook: Arc<dyn AgentHook>)
pub fn register(&mut self, hook: Arc<dyn AgentHook>)
Register a hook. Hooks are sorted by priority (lower runs first).
Sourcepub async fn run_hooks(
&self,
point: AgentHookPoint,
session: &Session,
runtime_state: &mut AgentRuntimeState,
) -> HookResult
pub async fn run_hooks( &self, point: AgentHookPoint, session: &Session, runtime_state: &mut AgentRuntimeState, ) -> HookResult
Run all hooks matching the given point.
Records checkpoints in runtime_state. Returns the first
Suspend or Abort result, or the aggregate result otherwise.
Sourcepub fn has_hooks_for(&self, point: AgentHookPoint) -> bool
pub fn has_hooks_for(&self, point: AgentHookPoint) -> bool
Check if any hooks are registered for the given point.