pub trait MiniLoopExecutor: Send + Sync {
// Required methods
fn decide<'life0, 'life1, 'life2, 'life3, 'async_trait>(
&'life0 self,
session: &'life1 Session,
prompt: &'life2 str,
context: &'life3 str,
) -> Pin<Box<dyn Future<Output = Result<MiniLoopDecision, AgentError>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait;
fn evaluate_task<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
session: &'life1 Session,
tool_calls: &'life2 [ToolCall],
round: usize,
) -> Pin<Box<dyn Future<Output = Result<MiniLoopDecision, AgentError>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait;
}Expand description
Executor for cheap model fast decisions.
Used for task evaluation, compression decisions, routing, retry classification, and other lightweight LLM-powered judgments that should not consume the main model’s budget or streaming path.
Required Methods
Sourcefn decide<'life0, 'life1, 'life2, 'life3, 'async_trait>(
&'life0 self,
session: &'life1 Session,
prompt: &'life2 str,
context: &'life3 str,
) -> Pin<Box<dyn Future<Output = Result<MiniLoopDecision, AgentError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
fn decide<'life0, 'life1, 'life2, 'life3, 'async_trait>(
&'life0 self,
session: &'life1 Session,
prompt: &'life2 str,
context: &'life3 str,
) -> Pin<Box<dyn Future<Output = Result<MiniLoopDecision, AgentError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
Execute a fast decision using a cheap model.
Sourcefn evaluate_task<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
session: &'life1 Session,
tool_calls: &'life2 [ToolCall],
round: usize,
) -> Pin<Box<dyn Future<Output = Result<MiniLoopDecision, AgentError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
fn evaluate_task<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
session: &'life1 Session,
tool_calls: &'life2 [ToolCall],
round: usize,
) -> Pin<Box<dyn Future<Output = Result<MiniLoopDecision, AgentError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
Evaluate task progress using a fast model.